@@ -3,5 +3,5 @@
 void Parser::display(RuleValue const &e)
 {
     if (!d_error)
-        cout << rvalue(e) << "\n";
+        cout << rvalue(e) << '\n';
 }
