@@ -88,6 +88,7 @@ class Generator
         bool grep(std::string const &fileName, std::string const &regex) 
                                                                         const;
 
+        std::ofstream tokenPath() const;
 
         void actionCases(std::ostream &out) const;
         void baseClass(std::ostream &out) const;
@@ -113,7 +114,9 @@ class Generator
         void namespaceClose(std::ostream &out) const;
         void namespaceOpen(std::ostream &out) const;
         void namespaceUse(std::ostream &out) const;
+        void notokens(std::ostream &out) const;
         void polymorphic(std::ostream &out) const;
+        void parserBase(std::ostream &out) const;
         void polyIncludes(std::ostream &out) const;
         void polymorphicCode(std::ostream &out) const;
         void polymorphicSpecializations(std::ostream &out) const;
@@ -129,6 +132,7 @@ class Generator
         void staticData(std::ostream &out) const;
         void stype(std::ostream &out) const;
         void tokens(std::ostream &out) const;
+        void undefparser(std::ostream &out) const;
         void warnTagMismatches(std::ostream &out) const;
 
         void ifInsertStype(bool &accept) const;
