@@ -12,5 +12,5 @@ void Scanner::returnTypeSpec()
 
     begin(StartCondition_::INITIAL);
 
-    leave(Parser::IDENTIFIER);
+    leave(Tokens::IDENTIFIER);
 }
